import re

from django.core.validators import (
    RegexValidator,
)


# TODO: вынести в пакет валидации ГАР
class HouseValidator(RegexValidator):
    """Валидатор номера дома.

    В ФИАС есть примеры, которые не подойдут под текущую регулярку, например:
    * АэропортШереметьево1
    * Ряд5Блок1Позиция1
    * IV-537
    * IX-7/34

    Эти дома относятся к "специальным" зданиям, хоз. помещениям на закрытых
    территориях (заводы, склады), гаражам и т.д.
    Если нужно будет, что бы они так же считались валидными,
    то регулярку нужно будет расширить до '^[0-9IVXа-яё/"_,.-]{1,20}$'
    """
    regex = re.compile(r'^[0-9а-яё/"_,.-]{0,12}$', re.IGNORECASE | re.UNICODE)
    message = 'Неверно указан номер дома'


class BuildingValidator(RegexValidator):
    """Валидатор номера корпуса дома."""
    regex = re.compile(r'^[0-9а-яё/_.-]{0,10}$', re.IGNORECASE | re.UNICODE)
    message = 'Неверно указан корпус дома'


# валидатор для полей моделей, содержащих коды адресных объектов
addr_field_validator = RegexValidator(
    regex=re.compile(
        '^$|^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',
        re.IGNORECASE
    ),
    message='Указан неверный код адресного объекта'
)

# Валидатор поля "Дом". 12 знаков, допускаются буквы, числа и знаки /"_.-
house_validator = HouseValidator()

# Валидатор для поля "Корпус". 10 знаков, допускаются буквы, числа и знаки /_.-
corps_validator = BuildingValidator()
