"""Удаление дубликатов записей из справочника Издательств."""
# Generated by Django 1.11.18 on 2019-08-14 09:28
from django.db import (
    connection,
    migrations,
    transaction,
)

from edulib.core.lib_publishings.models import (
    LibraryPublishings,
)
from edulib.core.lib_registry.models import (
    LibRegistryExample,
)


def delete_duplicates(apps, schema_editor):
    """Удаление дубликатов записей из справочника Издательств.

    Удаляются дубликаты записей из базы данных, с заменой ссылок на
    оставшиеся. При удалении из нескольких выбирается первая внесенная в базу.
    """
    with connection.cursor() as c:
        c.execute(
            """SELECT TRANSLATE(lower(name), 'Ё ', 'Е'), Min(id)
                FROM public.lib_publishings
                GROUP BY TRANSLATE(lower(name), 'Ё ', 'Е')
                HAVING COUNT(TRANSLATE(lower(name), 'Ё ', 'Е'))>1
                order by Min(id)
            """
        )
        rows = c.fetchall()
    with transaction.atomic():
        for lower_name, min_id in rows:
            duplicates = LibraryPublishings.objects.filter(
                name__smart_iexact=lower_name
            ).exclude(
                id=min_id
            )
            lib_examples = LibRegistryExample.objects.filter(
                publishing_id__in=duplicates.values('id')
            )
            lib_examples.update(publishing_id=min_id)
            duplicates.delete()


class Migration(migrations.Migration):  # noqa: D101

    dependencies = [
        ('lib_publishings', '0003_auto_20190327_1114'),
    ]

    operations = [
        migrations.RunPython(delete_duplicates, migrations.RunPython.noop)
    ]
